# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
# ======================================================================

__version__= '1.0'


ProductName = 'Button Builder'
ProductFolder = 'ButtonBuilder'





from Globals import HTML, HTMLFile, DTMLFile, MessageDialog, Persistent
import OFS,Acquisition, AccessControl.Role
import Globals, sys, traceback
from OFS.DTMLDocument import DTMLDocument

from OFS.History import Historical, html_diff
from OFS.SimpleItem import SimpleItem
from OFS.Cache import Cacheable

import StringIO,os

from PIL import Image,ImageDraw,ImageFont
import Products.PythonScripts

from webdav.common import rfc1123_date






class ButtonBuilder(OFS.SimpleItem.Item,DTMLDocument):
    """Zope object."""    
       
    meta_type = ProductName
    icon = 'misc_/%s/icon' % (ProductFolder)
    
    localdir = SOFTWARE_HOME+'/Products/'+ProductFolder
    
    manage_opt = HTMLFile('dtml/options', globals())
    demo = HTMLFile('dtml/demo', globals())

    formats = ['png','jpeg','bmp']


    #manage tabs
    manage_options=(
                    {'label':'Options','action':'manage_opt'},
                    {'label':'Demo','action':'demo'},
                    {'label':'build script','action':'build/manage_workspace'},
                   ) + Historical.manage_options + SimpleItem.manage_options + Cacheable.manage_options
                   

    def __init__(self, id, title):
        """ init method """
        self.id=id
        self.globals=''
        self._vars=''
        self.raw=''
        self.color_out=0xffffff        #on mouse out image
        self.color_over=0xff       #on mouse over image
        self.font='Times New Roman_8_200.pil'             #text font
        self.format = 'png'
        self.test_label = "Test Button"
        self.template_out = 'blue.png'
        self.template_over = 'blue.png'
        self.bgcolor = '#aaccff'
        self.width = 200
        
        self.build = Products.PythonScripts.PythonScript.PythonScript('build')
        self.build.ZPythonScript_setTitle('Demo usage button builder')
        self.build.ZPythonScript_edit('', build_body % (str(self.id)))
        



    def manage_opt_action(self,title,template_out,template_over,font,format,color_over,color_out,test_label,bgcolor,width,REQUEST=None):
        """
          Edit internal option (called from html form as its action)
        """
        self.title = title
        self.template_out = template_out
        self.template_over = template_over
        self.font = font
        self.format = format
        self.color_over = int(color_over,16)
        self.color_out = int(color_out,16)
        self.test_label = test_label
        self.bgcolor = bgcolor
        self.width = int(width)
        if REQUEST is not None:
            return Globals.MessageDialog( title='Edited', message='<strong>%s</strong> has been edited.' % self.id, action ='manage_opt',)
        else: return ""

    
    def index_html(self,REQUEST,RESPONSE,m='',f=0,t=''):
        """ default html file returned when view object """
        font = ImageFont.load_path(self.localdir+'/fonts/'+self.font)
        if(m==''):m=self.test_label
        mx,my=font.getsize(m) #message size
        if t=='':
            if(int(f)==0): im = Image.open(self.localdir+'/templates/'+self.template_out)
            else: im = Image.open(self.localdir+'/templates/'+self.template_over)
        else:
            im = Image.open(self.localdir+'/templates/'+t)
        ddx=10 #left,right border margin
        ddy=5  #top,bottom border margin
        if self.width==0:
            im=im.resize((2*ddx+mx,2*ddy+my))
        else:
            im=im.resize((self.width,2*ddy+my))
        draw = ImageDraw.Draw(im)
        dx,dy=im.size
        if(int(f)==0):
            draw.setink(self.color_out)
        else:
            draw.setink(self.color_over)
        draw.text((dx/2-mx/2,ddy),m,font=font)
        out=StringIO.StringIO()
        im.save(out ,self.format)
        RESPONSE.setHeader('Last-Modified', rfc1123_date(self._p_mtime))
        RESPONSE.setHeader('Content-Type', 'image/'+self.format)
        RESPONSE.setHeader('Content-Length', out.len)
        RESPONSE.write(out.getvalue())
        #print f,out.len    #I use this print to test web browser cache

    def fontList(self):
        #return list of available fonts (used in options tab)
        L=[]
        for f in os.listdir(self.localdir+'/fonts/'):
            if(f[-4:] == '.pil'): L.append(f)
        return L

    def templateList(self):
        #list of available button templates
        return os.listdir(self.localdir+'/templates/')





Globals.default__class_init__(ButtonBuilder)

build_body='''
#
#Copy and paste this python script into your program
#(C) 2003 Ioan Coman, http://www.zope.org/Members/Ioan/
#
#edit this script to fit your needs
#


#edit this list
button_list=[
 {'title':'Zope','url':'http://www.zope.org/'},
 {'title':'OpenBSD','url':'http://www.openbsd.org/'},
 {'title':'My Site','url':'http://ioan.freezope.org/'}
]

#edit this variable if you'll use another button builder object
bb = context.%s.absolute_url()


#remove/change this html header (and also html footer)
print """
<html>
<head>
 <title>Buttons</title>
</head>

<body bgcolor="#aaccff" link="#000099" vlink="#555555" alink="#77003B" onload="preload_images();">
"""



#the rest must stay unchanged
print """
<script language="JavaScript" type="text/javascript">
var preloaded = false;
var preloaded_images = new Array;

function load_image(src, name)
{
  var im = new Image();
  im.src = src;
  preloaded_images[name] = im;
}

function roll_over(img, new_img)
{
  if (document.images && preloaded)
  {
   document.images[img].src = preloaded_images[new_img].src;
  }
}

function preload_images()
{
"""
pos=0
for i in button_list:
  print "  load_image('%%s?f=1&m=%%s', 'b%%d_over');" %% (bb,i['title'],pos)
  print "  load_image('%%s?f=0&m=%%s', 'b%%d_out' );" %% (bb,i['title'],pos)
  pos=pos+1
print """
  preloaded = true;
}
</script>
"""

pos=0
for i in button_list:
 print """
<a href="%%s"
onmouseover="roll_over('b%%d', 'b%%d_over');"
onmouseout ="roll_over('b%%d', 'b%%d_out');"
><img src="%%s?f=0&m=%%s" name="b%%d" id="b%%d" border="0"></a><br>
""" %% (i['url'],
        pos,pos,
        pos,pos,
        bb,i['title'],pos,pos)
 pos=pos+1



#remove/change this html html footer
print context.standard_html_footer(context)

return printed

'''
